Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8253)

Unified Diff: chrome/test/data/extensions/api_test/permissions/optional/background.js

Issue 1665563003: Ask for notification permission during extension installation. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/extensions/api_test/permissions/optional/background.js
diff --git a/chrome/test/data/extensions/api_test/permissions/optional/background.js b/chrome/test/data/extensions/api_test/permissions/optional/background.js
index e0c2f64d4ee16d753a508b0a6a725dd19463b88c..2bf1e17b254872dd0f2489ead96c4565b05c9347 100644
--- a/chrome/test/data/extensions/api_test/permissions/optional/background.js
+++ b/chrome/test/data/extensions/api_test/permissions/optional/background.js
@@ -206,13 +206,13 @@ chrome.test.getConfig(function(config) {
// The user shouldn't have to approve permissions that have no warnings.
function noPromptForNoWarnings() {
chrome.permissions.request(
- {permissions: ['notifications']},
+ {permissions: ['cookies']},
pass(function(granted) {
assertTrue(granted);
// Remove the notifications permission to return to normal.
chrome.permissions.remove(
- {permissions: ['notifications']},
+ {permissions: ['cookies']},
pass(function(removed) { assertTrue(removed); }));
}));
},
@@ -206,13 +206,13 @@ chrome.test.getConfig(function(config) {
pass(function(granted) {
assertTrue(granted);
- // Remove the notifications permission to return to normal.
+ // Remove the cookies permission to return to normal.
chrome.permissions.remove(

Powered by Google App Engine
This is Rietveld 408576698